package com.ynet.gene.web.servlet.mvc;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.DataElement;
import com.ynet.gene.data.DataField;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.datatype.DataType;
import com.ynet.gene.datatype.InvalidDataException;
import com.ynet.gene.flow.GENEBusinessLogic;
import com.ynet.gene.flow.GENEFlow;
import com.ynet.gene.log.GENELog;
import com.ynet.gene.web.multipart.MultipartHttpServletRequest;
import java.util.Enumeration;
import java.util.Locale;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_ynet_gene_web_servlet_mvc.jar:com/ynet/gene/web/servlet/mvc/GENEModelUpdater.class */
public class GENEModelUpdater implements ModelUpdater {
    private boolean withoutICollId = false;
    private String viewId;
    KeyedCollection kColl;

    public void updateModel(HttpServletRequest request, Context context, Map dataTypeDefs, boolean append) throws GENEException {
        if (getKeyedCollection() != null) {
            updateContextWithKeyedCollection(request, getKeyedCollection(), context, dataTypeDefs);
        } else {
            updateContextDirect(request, context, dataTypeDefs, append);
        }
    }

    public void updateModel(HttpServletRequest request, Context context, GENEFlow flow, String opId, Map dataTypeDefs, boolean append) throws GENEException {
        if (getKeyedCollection() != null) {
            updateContextWithKeyedCollection(request, getKeyedCollection(), context, dataTypeDefs);
            return;
        }
        if (flow instanceof GENEBusinessLogic) {
            KeyedCollection keyedCollection = (KeyedCollection) ((GENEBusinessLogic) flow).getInput(opId);
            KeyedCollection kColl = keyedCollection;
            if (keyedCollection == null) {
                kColl = new KeyedCollection("empty");
            }
            updateContextWithKeyedCollection(request, kColl, context, dataTypeDefs);
            return;
        }
        updateContextDirect(request, context, dataTypeDefs, append);
    }

    private void updateContextDirect(HttpServletRequest request, Context context, Map dataTypeDefs, boolean append) throws GENEException {
        boolean haveInputException = false;
        Map files = null;
        if (request instanceof MultipartHttpServletRequest) {
            files = ((MultipartHttpServletRequest) request).getFiles();
        }
        Enumeration names = request.getParameterNames();
        while (names.hasMoreElements()) {
            String name = (String) names.nextElement();
            Object value = request.getParameter(name);
            if (files != null && files.get(name) != null) {
                value = files.get(name);
            }
            DataElement dstDataElement = null;
            try {
                dstDataElement = context.getDataElement(name);
            } catch (Exception unused) {
            }
            if (dstDataElement == null) {
                if (append) {
                    dstDataElement = new DataField(name);
                    context.addDataElement(dstDataElement);
                } else {
                    GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Posted DataField  " + name + ":" + value + " not defined in context!");
                }
            }
            String dataType = ((DataField) dstDataElement).getDataType();
            if (dataType != null) {
                try {
                    Object objValue = ((DataType) dataTypeDefs.get(dataType)).convertFromString(value.toString(), (Locale) null);
                    context.setDataValue(name, objValue);
                } catch (InvalidDataException e) {
                    haveInputException = true;
                    String msg = e.getMessage();
                    addErrorMessage(context, dstDataElement.getName(), msg, e);
                    GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Invalid dataValue DataField  " + name + " = " + value, e);
                }
            } else {
                context.setDataValue(name, value);
            }
            GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Posted DataField  " + name + " = " + value);
            if (haveInputException) {
                throw new InvalidInputException();
            }
        }
    }

    private void addErrorMessage(Context context, String dataName, String msg, GENEException dataException) {
        DataElement keyedCollection;
        DataElement keyedCollection2;
        try {
            try {
                keyedCollection = (KeyedCollection) context.getDataElement(GENEConstance.ERROR_MSG_KCOLL);
            } catch (Exception unused) {
                keyedCollection = new KeyedCollection(GENEConstance.ERROR_MSG_KCOLL);
                context.addDataElement(keyedCollection);
            }
            try {
                keyedCollection2 = (KeyedCollection) context.getDataElement(GENEConstance.ERROR_EXCEPTION_KCOLL);
            } catch (Exception unused2) {
                keyedCollection2 = new KeyedCollection(GENEConstance.ERROR_EXCEPTION_KCOLL);
                context.addDataElement(keyedCollection2);
            }
            keyedCollection.addDataField(dataName, msg);
            keyedCollection2.addDataField(dataName, dataException);
        } catch (Exception unused3) {
        }
    }

    private void updateContextWithKeyedCollection(HttpServletRequest request, KeyedCollection kColl, Context context, Map dataTypeDefs) throws GENEException {
        Map files = null;
        if (request instanceof MultipartHttpServletRequest) {
            files = ((MultipartHttpServletRequest) request).getFiles();
        }
        boolean haveInputException = false;
        for (int i = 0; i < kColl.size(); i++) {
            ViewField dataElement = kColl.getDataElement(i);
            String name = dataElement.getName();
            if (dataElement instanceof IndexedCollection) {
                IndexedCollection iColl = (IndexedCollection) dataElement;
                updateContextIColl(request, iColl, context, dataTypeDefs);
            } else {
                DataField dataField = (DataField) dataElement;
                String dataName = dataElement.getName();
                Object value = request.getParameter(dataName);
                if (files != null && files.get(name) != null) {
                    value = files.get(name);
                }
                String dstFieldName = dataField.getName();
                if (dataElement instanceof ViewField) {
                    dstFieldName = dataElement.getDstDataName();
                }
                DataField dstDataElement = context.getDataElement(dstFieldName);
                if ((value == null || value == "") && dataField.isRequired()) {
                    addErrorMessage(context, dataName, "Required field ", null);
                    haveInputException = true;
                    GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Required field  " + dataName + "Not posted!");
                } else {
                    String dataType = dstDataElement.getDataType();
                    if (dataType != null && value != null) {
                        try {
                            DataType dataTypeDef = (DataType) dataTypeDefs.get(dataType);
                            if (dataTypeDef == null) {
                                throw new GENEException("DataType named [" + dataType + "] not defined in update dataModel for data [" + dataName + "]!");
                                break;
                            } else {
                                Object objValue = dataTypeDef.convertFromString(value.toString(), (Locale) null);
                                context.setDataValue(dstFieldName, objValue);
                            }
                        } catch (InvalidDataException e) {
                            haveInputException = true;
                            String msg = e.getMessage();
                            addErrorMessage(context, dstDataElement.getName(), msg, e);
                            GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Invalid dataValue DataField  " + dataName + " = " + value, e);
                        }
                    } else {
                        context.setDataValue(dstFieldName, value);
                    }
                    GENELog.log(GENEConstance.GENE_MVC, GENELog.DEBUG, 0, "Posted DataField  " + name + " = " + value);
                }
            }
        }
        if (haveInputException) {
            throw new InvalidInputException();
        }
    }

    private void updateContextIColl(HttpServletRequest request, IndexedCollection iColl, Context context, Map dataTypeDefs) throws GENEException {
        DataElement aElement;
        DataElement dataElement;
        KeyedCollection dataElement2 = iColl.getDataElement();
        String iCollName = iColl.getName();
        IndexedCollection targetColl = context.getDataElement(iCollName);
        DataElement targetElement = targetColl.getDataElement();
        if (dataElement2 instanceof KeyedCollection) {
            Object[] keys = dataElement2.keySet().toArray();
            for (Object obj : keys) {
                String name = (String) obj;
                String[] values = request.getParameterValues(iCollName + "." + name);
                if ((request instanceof MultipartHttpServletRequest) && values != null && values.length > 0 && StringUtils.isNotEmpty(values[0])) {
                    values = values[0].split(",");
                }
                if (values == null) {
                    values = request.getParameterValues(iCollName + "." + name + "[]");
                }
                if (values == null && this.withoutICollId) {
                    values = request.getParameterValues(name);
                }
                if (values != null) {
                    for (int k = 0; k < values.length; k++) {
                        if (k < targetColl.size()) {
                            dataElement = (KeyedCollection) targetColl.getElementAt(k);
                        } else {
                            dataElement = (KeyedCollection) targetElement.clone();
                            targetColl.addDataElement(dataElement);
                        }
                        dataElement.setDataValue(name, values[k]);
                    }
                }
            }
            return;
        }
        String name2 = ((DataField) dataElement2).getName();
        String[] values2 = request.getParameterValues(iCollName + "." + name2);
        if (values2 != null) {
            for (int k2 = 0; k2 < values2.length; k2++) {
                if (k2 < targetColl.size()) {
                    aElement = targetColl.getElementAt(k2);
                } else {
                    aElement = (DataElement) targetElement.clone();
                    targetColl.addDataElement(aElement);
                }
                if (aElement instanceof KeyedCollection) {
                    ((KeyedCollection) aElement).setDataValue(name2, values2[k2]);
                } else {
                    ((DataField) aElement).setValue(values2[k2]);
                }
            }
        }
    }

    public void setKeyedCollection(KeyedCollection kColl) {
        this.kColl = kColl;
    }

    public KeyedCollection getKeyedCollection() {
        return this.kColl;
    }

    public String getViewId() {
        return this.viewId;
    }

    public void setViewId(String viewId) {
        this.viewId = viewId;
    }

    public String getViewName() {
        return this.viewId;
    }

    public void updateModel(HttpServletRequest request, Context context, GENEFlow flow, String opId, Map dataTypeDefs) throws GENEException {
        updateModel(request, context, flow, opId, dataTypeDefs, false);
    }

    public void updateModel(HttpServletRequest request, Context context, Map dataTypeDefs) throws GENEException {
        updateModel(request, context, dataTypeDefs, false);
    }

    public void setWithoutICollId(boolean flag) {
        this.withoutICollId = flag;
    }
}
